@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "solarized-theme" "2.0.5"
+(define-package "solarized-theme" "20250913.451"
   "The Solarized color theme."
   '((emacs "24.1"))
-  :url "https://github.com/bbatsov/solarized-emacs"
-  :commit "5d136736f76c85a83fef737d10ecd32af4d493fd"
-  :revdesc "5d136736f76c"
+  :url "http://github.com/bbatsov/solarized-emacs"
+  :commit "65f6772119462f2e91a9d70f0c4e1085bddd29c9"
+  :revdesc "65f677211946"
   :keywords '("convenience" "themes" "solarized")
   :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
   :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
